==> kubernetes-model-1.0.37-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/HorizontalPodAutoscalerSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class HorizontalPodAutoscalerSpecBuilder extends HorizontalPodAutoscalerSpecFluentImpl<HorizontalPodAutoscalerSpecBuilder> implements VisitableBuilder<HorizontalPodAutoscalerSpec,HorizontalPodAutoscalerSpecBuilder>{

     HorizontalPodAutoscalerSpecFluent<?> fluent;
public HorizontalPodAutoscalerSpecBuilder(){
    this(new HorizontalPodAutoscalerSpec());
}
public HorizontalPodAutoscalerSpecBuilder( HorizontalPodAutoscalerSpecFluent<?> fluent ){
    this(fluent, new HorizontalPodAutoscalerSpec());
}
public HorizontalPodAutoscalerSpecBuilder( HorizontalPodAutoscalerSpecFluent<?> fluent , HorizontalPodAutoscalerSpec instance ){
    this.fluent = fluent; fluent.withCpuUtilization(instance.getCpuUtilization()); fluent.withMaxReplicas(instance.getMaxReplicas()); fluent.withMinReplicas(instance.getMinReplicas()); fluent.withScaleRef(instance.getScaleRef()); 
}
public HorizontalPodAutoscalerSpecBuilder( HorizontalPodAutoscalerSpec instance ){
    this.fluent = this; this.withCpuUtilization(instance.getCpuUtilization()); this.withMaxReplicas(instance.getMaxReplicas()); this.withMinReplicas(instance.getMinReplicas()); this.withScaleRef(instance.getScaleRef()); 
}

public EditableHorizontalPodAutoscalerSpec build(){
    EditableHorizontalPodAutoscalerSpec buildable = new EditableHorizontalPodAutoscalerSpec(fluent.getCpuUtilization(),fluent.getMaxReplicas(),fluent.getMinReplicas(),fluent.getScaleRef());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
HorizontalPodAutoscalerSpecBuilder that = (HorizontalPodAutoscalerSpecBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.51-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/HorizontalPodAutoscalerSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import java.util.Map;
import java.util.HashMap;
import java.io.Serializable;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class HorizontalPodAutoscalerSpecBuilder extends HorizontalPodAutoscalerSpecFluentImpl<HorizontalPodAutoscalerSpecBuilder> implements VisitableBuilder<HorizontalPodAutoscalerSpec,HorizontalPodAutoscalerSpecBuilder>{

     HorizontalPodAutoscalerSpecFluent<?> fluent;
public HorizontalPodAutoscalerSpecBuilder(){
    this(new HorizontalPodAutoscalerSpec());
}
public HorizontalPodAutoscalerSpecBuilder( HorizontalPodAutoscalerSpecFluent<?> fluent ){
    this(fluent, new HorizontalPodAutoscalerSpec());
}
public HorizontalPodAutoscalerSpecBuilder( HorizontalPodAutoscalerSpecFluent<?> fluent , HorizontalPodAutoscalerSpec instance ){
    this.fluent = fluent; fluent.withCpuUtilization(instance.getCpuUtilization()); fluent.withMaxReplicas(instance.getMaxReplicas()); fluent.withMinReplicas(instance.getMinReplicas()); fluent.withScaleRef(instance.getScaleRef()); 
}
public HorizontalPodAutoscalerSpecBuilder( HorizontalPodAutoscalerSpec instance ){
    this.fluent = this; this.withCpuUtilization(instance.getCpuUtilization()); this.withMaxReplicas(instance.getMaxReplicas()); this.withMinReplicas(instance.getMinReplicas()); this.withScaleRef(instance.getScaleRef()); 
}

public HorizontalPodAutoscalerSpec build(){
    HorizontalPodAutoscalerSpec buildable = new HorizontalPodAutoscalerSpec(fluent.getCpuUtilization(),fluent.getMaxReplicas(),fluent.getMinReplicas(),fluent.getScaleRef());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
HorizontalPodAutoscalerSpecBuilder that = (HorizontalPodAutoscalerSpecBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
